import nodeApi from './node.api';

import { Configuration } from 'webpack';

const mockReactStaticArgs = {
  stage: 'node' as 'node',
  defaultLoaders: {
    jsLoader: { loader: 'js' },
    jsLoaderExt: { loader: 'jsExt' },
    cssLoader: { loader: 'css' },
    fileLoader: { loader: 'file' },
  },
};

it('should add a loader for .tsx and .ts files', () => {
  const webpackConfig = {};

  const updatedWebpackConfig = nodeApi().webpack(webpackConfig, mockReactStaticArgs);

  const fileMatchRegEx = updatedWebpackConfig.module.rules[0].oneOf[0].test as RegExp;
  expect(fileMatchRegEx.test('typeScriptFile.tsx')).toBe(true);
  expect(fileMatchRegEx.test('typeScriptFile.ts')).toBe(true);
});

it('should preserve the default loaders', () => {
  const webpackConfig = {};

  const updatedWebpackConfig = nodeApi().webpack(webpackConfig, mockReactStaticArgs);

  expect(updatedWebpackConfig.module.rules[0].oneOf[0])
    .not.toEqual(mockReactStaticArgs.defaultLoaders.jsLoader);
  expect(updatedWebpackConfig.module.rules[0].oneOf[1])
    .toEqual(mockReactStaticArgs.defaultLoaders.jsLoaderExt);
  expect(updatedWebpackConfig.module.rules[0].oneOf[2])
    .toEqual(mockReactStaticArgs.defaultLoaders.cssLoader);
  expect(updatedWebpackConfig.module.rules[0].oneOf[3])
    .toEqual(mockReactStaticArgs.defaultLoaders.fileLoader);
});

it('should tell React Static that pages can have .ts or .tsx extensions', () => {
  const reactStaticConfig = { extensions: [] };

  const updatedReactStaticConfig = nodeApi().config(reactStaticConfig);

  expect(updatedReactStaticConfig.extensions).toEqual(['.ts', '.tsx']);
});

it('should preserve existing extensions for pages', () => {
  const reactStaticConfig = { extensions: [ '.1337' ] };

  const updatedReactStaticConfig = nodeApi().config(reactStaticConfig);

  expect(updatedReactStaticConfig.extensions).toEqual(['.1337', '.ts', '.tsx']);
});
